import string
from clickzetta.proto.generated import metadata_entity_pb2, ingestion_pb2, table_meta_pb2


class CZTable:
    def __init__(self, table_meta: ingestion_pb2.StreamSchema, schema_name: string, table_name: string):
        self.schema_name = schema_name
        self.table_name = table_name
        self.table_meta = table_meta
        self.schema = {}
        fields = table_meta.data_fields
        for field in fields:
            self.schema[field.name] = field.type




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network_policy.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14network_policy.proto\x12\x08\x63z.proto\"=\n\rNetworkPolicy\x12,\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1b.cz.proto.NetworkPolicyData\"j\n\x11NetworkPolicyData\x12\x15\n\rworkspaceList\x18\x01 \x03(\t\x12\x14\n\x0cusernameList\x18\x02 \x03(\t\x12\x13\n\x0b\x62lockedList\x18\x03 \x03(\t\x12\x13\n\x0b\x61llowedList\x18\x04 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'network_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NETWORKPOLICY']._serialized_start=34
  _globals['_NETWORKPOLICY']._serialized_end=95
  _globals['_NETWORKPOLICYDATA']._serialized_start=97
  _globals['_NETWORKPOLICYDATA']._serialized_end=203
# @@protoc_insertion_point(module_scope)



from clickzetta.dbapi.connection import Connection
from clickzetta.dbapi.connection import connect
from clickzetta.dbapi.cursor import Cursor
from clickzetta.dbapi.types import Binary
from clickzetta.dbapi.types import Date
from clickzetta.dbapi.types import DateFromTicks
from clickzetta.dbapi.types import Time
from clickzetta.dbapi.types import Timestamp
from clickzetta.dbapi.types import TimestampFromTicks
from clickzetta.dbapi.types import BINARY
from clickzetta.dbapi.types import DATETIME
from clickzetta.dbapi.types import NUMBER
from clickzetta.dbapi.types import STRING
from clickzetta.dbapi.types import ROWID
from clickzetta.dbapi.exceptions import Warning
from clickzetta.dbapi.exceptions import Error
from clickzetta.dbapi.exceptions import InternalError
from clickzetta.dbapi.exceptions import DatabaseError
from clickzetta.dbapi.exceptions import OperationalError
from clickzetta.dbapi.exceptions import IntegrityError
from clickzetta.dbapi.exceptions import InterfaceError
from clickzetta.dbapi.exceptions import ProgrammingError
from clickzetta.dbapi.exceptions import NotSupportedError
from clickzetta.dbapi.exceptions import DataError



threadsafety = 2
paramstyle = "pyformat"

__all__ = [
    "threadsafety",
    "paramstyle",
    "Connection",
    "connect",
    "Cursor",
    "Binary",
    "Date",
    "DateFromTicks",
    "Time",
    "Timestamp",
    "TimestampFromTicks",
    "BINARY",
    "DATETIME",
    "NUMBER",
    "STRING",
    "ROWID",
    "Warning",
    "Error",
    "InterfaceError",
    "DatabaseError",
    "DataError",
    "OperationalError",
    "IntegrityError",
    "InternalError",
    "ProgrammingError",
    "NotSupportedError",
]